ProSHADE: Namespace Members

| ProSHADE 0.7.5.1 (JAN 2021) Protein Shape Detection

### - g -

- gaussLegendreIntegration() : ProSHADE_internal_maths
- gaussLegendreIntegrationReal() : ProSHADE_internal_maths
- generateMapFromPDB() : ProSHADE_internal_mapManip
- generateSO3CoeffsFromEMatrices() : ProSHADE_internal_distances
- getAllPeaksNaive() : ProSHADE_internal_peakSearch
- getAllPeaksSmoothedZ() : ProSHADE_internal_peakSearch
- getAxisAngleFromRotationMatrix() : ProSHADE_internal_maths
- getBestPeakEulerAngsNaive() : ProSHADE_internal_peakSearch
- getBestPeakEulerAngsSmoothedZ() : ProSHADE_internal_peakSearch
- getCorrelationMapMask() : ProSHADE_internal_mapManip
- getEulerZXZFromAngleAxis() : ProSHADE_internal_maths
- getEulerZXZFromAngleAxisFullSearch() : ProSHADE_internal_maths
- getEulerZXZFromRotMatrix() : ProSHADE_internal_maths
- getEulerZXZFromSOFTPosition() : ProSHADE_internal_maths
- getFakeHalfMap() : ProSHADE_internal_mapManip
- getGLFirstEvenRoot() : ProSHADE_internal_maths
- getGLPolyAtZero() : ProSHADE_internal_maths
- getIndicesFromAngstroms() : ProSHADE_internal_mapManip
- getLegendreAbscAndWeights() : ProSHADE_internal_maths
- getMaskFromBlurr() : ProSHADE_internal_mapManip
- getNonZeroBounds() : ProSHADE_internal_mapManip
- getOptimalRotation() : ProSHADE_internal_overlay
- getOptimalTranslation() : ProSHADE_internal_overlay
- getPeaksAngleAxisPositions() : ProSHADE_internal_symmetry
- getRotationMatrixFromAngleAxis() : ProSHADE_internal_maths
- getRotationMatrixFromEulerZXZAngles() : ProSHADE_internal_maths
- getSmoothedZScore1D() : ProSHADE_internal_peakSearch
- getSOFTPositionFromEulerZXZ() : ProSHADE_internal_maths
- getXAxisArraysSmoothedZScorePeaks() : ProSHADE_internal_peakSearch
- getYAxisArraysSmoothedZScorePeaks() : ProSHADE_internal_peakSearch
- getZAxisArraysSmoothedZScorePeaks() : ProSHADE_internal_peakSearch
- giveOppositeAxesSameDirection() : ProSHADE_internal_symmetry
- groupSameAxes() : ProSHADE_internal_symmetry